@@ -374,7 +374,7 @@ class CurveBuilder:
         elif curve_type == CurveType.ARC:
             curves = self.arcs_from_points(points)
         elif curve_type == CurveType.CUBICBEZIER:
-            curves = self.beziers_from_points(points)
+            curves = self.cubicbeziers_from_points(points)
 
         return curves
 
@@ -396,9 +396,10 @@ class CurveBuilder:
                               )
         return curves
 
-    def beziers_from_points(self, points):
+    def cubicbeziers_from_points(self, points):
         curves = []
-        for ii in range(0, len(points) - 4, 3):
+        # A Cubic Bezier requires 4 control points, so operate in blocks of 4 (re-using the last each time)
+        for ii in range(0, len(points) - 3, 3):
             curves.append(CubicBezier(self.id_provider(), points[ii:ii+3]))
         return curves
 
